package com.tmerclub.cloud.cuerecycle.controller.admin;

import com.tmerclub.cloud.common.database.vo.PageVO;
import com.tmerclub.cloud.common.response.ServerResponseEntity;
import com.tmerclub.cloud.cuerecycle.model.dto.CueOrderDTO;
import com.tmerclub.cloud.cuerecycle.model.vo.CueOrderVO;
import com.tmerclub.cloud.common.database.dto.PageDTO;
import com.tmerclub.cloud.cuerecycle.service.CueOrderService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

/**
 * 回收订单
 *
 * @author : frank
 * @create : 2025-04-15
 */
@Tag(name = "后管-回收订单")
@RestController("adminCueOrderController")
@RequestMapping("/admin/cueOrder")
public class CueOrderController {
    @Resource
    CueOrderService cueOrderService;

   /**
    * 分页查询
    *
    * @param pageDTO         分页参数
    * @param cueOrderDTO 查询参数
    * @return 分页数据
    */
    @GetMapping("/page")
    @Operation(summary = "查询回收订单分页列表", description = "查询回收订单分页列表")
    public ServerResponseEntity<PageVO<CueOrderVO>> page(@Valid PageDTO pageDTO, CueOrderDTO cueOrderDTO) {
        PageVO<CueOrderVO> cueOrderPage = cueOrderService.page(pageDTO, cueOrderDTO);
        return ServerResponseEntity.success(cueOrderPage);
    }


    /**
     * 根据主键id获取回收订单
     *
     * @param id 主键id
     * @return CueOrderVO
     */
    @GetMapping
    @Operation(summary = "根据id获取回收订单", description = "根据id获取回收订单")
    public ServerResponseEntity<CueOrderVO> getById(@RequestParam Long id) {
        CueOrderVO cueOrder = cueOrderService.getById(id);
        return ServerResponseEntity.success(cueOrder);
    }

    /**
     * 新增回收订单
     *
     * @param cueOrderDTO CueOrderDTO
     * @return ServerResponseEntity
     */
    @PostMapping
    @Operation(summary = "新增回收订单", description = "新增回收订单")
    public ServerResponseEntity<Void> save(@Valid @RequestBody CueOrderDTO cueOrderDTO) {
        int insert = cueOrderService.save(cueOrderDTO);
        return insert > 0 ? ServerResponseEntity.success() : ServerResponseEntity.showFailMsg("保存失败");
    }

    /**
     * 修改回收订单
     *
     * @param cueOrderDTO CueOrderDTO
     * @return ServerResponseEntity
     */
    @PutMapping
    @Operation(summary = "修改回收订单", description = "修改回收订单")
    public ServerResponseEntity<Void> update(@Valid @RequestBody CueOrderDTO cueOrderDTO) {
        int update = cueOrderService.update(cueOrderDTO);
        return update > 0 ? ServerResponseEntity.success() : ServerResponseEntity.showFailMsg("修改失败");
    }

    /**
     * 删除回收订单
     *
     * @param id 主键id
     * @return ServerResponseEntity
     */
    @DeleteMapping
    @Operation(summary = "删除回收订单", description = "删除回收订单")
    public ServerResponseEntity<Void> delete(@RequestParam Long id) {
        int delete = cueOrderService.delete(id);
        return delete > 0 ? ServerResponseEntity.success() : ServerResponseEntity.showFailMsg("删除失败");
    }
}