
package com.tmerclub.cloud.order.mapper;

import com.tmerclub.cloud.common.order.vo.OrderSelfStationVO;
import com.tmerclub.cloud.order.model.OrderSelfStation;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 自提订单自提点信息
 *
 * @author tmerclub
 * @date 2020-12-05 14:13:50
 */
public interface OrderSelfStationMapper {

    /**
     * 获取自提订单自提点信息列表
     * @return 自提订单自提点信息列表
     */
    List<OrderSelfStationVO> list();

    /**
     * 根据自提订单自提点信息id获取自提订单自提点信息
     *
     * @param id 自提订单自提点信息id
     * @return 自提订单自提点信息
     */
    OrderSelfStationVO getById(@Param("id") Long id);

    /**
     * 保存自提订单自提点信息
     * @param orderSelfStation 自提订单自提点信息
     */
    void save(@Param("orderSelfStation") OrderSelfStation orderSelfStation);


    /**
     * 批量保存自提订单自提点信息
     *
     * @param orderSelfStations 自提订单自提点信息
     */
    void saveBatch(@Param("orderSelfStations") List<OrderSelfStation> orderSelfStations);

    /**
     * 更新自提订单自提点信息
     * @param orderSelfStation 自提订单自提点信息
     */
    void update(@Param("orderSelfStation") OrderSelfStation orderSelfStation);

    /**
     * 根据自提订单自提点信息id删除自提订单自提点信息
     * @param id
     */
    void deleteById(@Param("id") Long id);

    /**
     * 根据用户id获取用户自提订单信息
     *
     * @param userId 用户id
     * @return 用户自提订单信息
     */
    List<OrderSelfStation> getStationUserInfo(@Param("userId") Long userId);

    /**
     * 根据订单号获取用户自提订单信息
     *
     * @param orderId 订单号
     * @return 用户自提订单信息
     */
    OrderSelfStationVO getStationByOrderId(@Param("orderId") Long orderId);

    /**
     * 根据用户id获取用户自提信息
     *
     * @param userId 用户id
     * @return 用户自提信息
     */
    List<OrderSelfStationVO> getUserStation(@Param("userId") Long userId);

    /**
     * 根据用户id获取待核销的自提订单
     * @param userId 用户id
     * @param stationId 自提点id
     * @param shopId 店铺id
     * @return
     */
    List<OrderSelfStationVO> getOrderSelfStationByStationIdOrShopId(@Param("userId") Long userId, @Param("stationId") Long stationId, @Param("shopId") Long shopId);

    /**
     * 根据订单ids获取对应的自提信息
     * @param orderIds
     * @return
     */
    List<OrderSelfStationVO> listSelfStationByOrderIds(@Param("orderIds") List<Long> orderIds);
}
